@@ -1,4 +1,4 @@
 library(testthat)
 library(simphony)
 
-test_check("simphony")
+test_check('simphony')
